<a href="{{ photo.get_absolute_url }}"><img src="{{ photo.image_square_source }}" alt="{{ photo.title }}" /></a>
<div class="flickrsets-item-info">
    <h4><a href="{{ photo.get_absolute_url }}">{{ photo.title }}</a></h4>
</div>