from flickrsets.tests.client import FlickrClientTest
from flickrsets.tests.client import FakeClient

from flickrsets.tests.models import PersonTest
from flickrsets.tests.models import PersonManagerTest
from flickrsets.tests.models import PhotoTest
from flickrsets.tests.models import PhotoManagerTest
from flickrsets.tests.models import PhotosetTest
from flickrsets.tests.models import PhotosetManagerTest
from flickrsets.tests.models import TagTest
from flickrsets.tests.models import TagManagerTest

from flickrsets.tests.parsers import PersonParserTest
from flickrsets.tests.parsers import PhotoParserTest
from flickrsets.tests.parsers import PhotosetParserTest
from flickrsets.tests.parsers import PhotoTagsParserTest

from flickrsets.tests.templatetags import PhotoFlickrUrlsNodeTest

from flickrsets.tests.views import ViewsTest
